@@ -4,7 +4,7 @@ from enum import Enum, auto
 
 
 class SocketKind(Enum):
-    SOCK_STREAM = auto() 
+    SOCK_STREAM = auto()
     SOCK_DGRAM = auto()
 
 
@@ -37,6 +37,9 @@ class SocketAsync():
         self.__timeout = value
 
     async def connect(self, remote_addr):
+        await asyncio.wait_for(self.__connect(remote_addr), timeout=self.__timeout)
+
+    async def __connect(self, remote_addr):
         loop = asyncio.get_running_loop()
         self.__protocol = self.__Protocol(self.__timeout)
 
@@ -86,7 +89,10 @@ class SocketAsync():
 
         # Streaming Protocols
         def eof_received(self):
-            """Called when the other end signals it won't send any more data (for example by calling transport.write_eof(), if the other end also uses asyncio)."""
+            """
+            Called when the other end signals it won't send any more data
+            (for example by calling transport.write_eof(), if the other end also uses asyncio).
+            """
             pass
 
         # Datagram Protocols
